==> jdreact-core-web-0.0.1.tgz: package/local-cli/generator-web/index.js <==
/**
 * Copyright (c) 2015-present, jd Group Holding Limited.
 * All rights reserved.
 */
'use strict';

var path = require('path');
var easyfile = require('easyfile');
var fs = require('fs');
module.exports = function(rootDir) {
  var src = path.join(__dirname, '/templates/');
  var dest = path.join(rootDir, 'web/');
  easyfile.copy(src, dest, {
    force: true,
    backup: true,
  });
  /**
   * 拷贝 react-dom.development.js 至 node_modules/react-dom/cjs/react-dom.development.js
   */
  easyfile.copy(rootDir +'/node_modules/@jdreact/jdreact-core-scripts/patch/react-dom/cjs/react-dom.development.js',
    rootDir +'/node_modules/react-dom/cjs/react-dom.development.js', {
     force: true,
     backup: false,
  });
  /**
   * 拷贝 version 文件至 web 目录下，并修改 moduleName
   */
  let fileName = process.cwd().split('-').pop()+'.version';
  let moduleName = process.cwd().split('-').pop();
  if(!easyfile.isFile(fileName)){
    var allfiles = fs.readdirSync(process.cwd()+'/jsbundles/');
    allfiles.forEach(function(item, index){
      if(path.extname(item) == '.version'){
        fileName = item;
        moduleName = path.basename(item,".version");
      }
    })
  }
  let sourceFile = path.join(process.cwd()+'/jsbundles/', fileName);
  let destFile = path.join(rootDir, 'web/version.json' );
  easyfile.copy(sourceFile, destFile, {
    force: true,
    backup: true,
  });

  /**
   * 修改moduleName
   */
  fs.readFile(destFile,'utf8',function (err, data) {
    if(err) console.log(err);
    var version = JSON.parse(data);
    version.moduleName = moduleName;
    var t = JSON.stringify(version);
    fs.writeFileSync(destFile,t);
  });

}

==> jdreact-core-web-0.0.6.tgz: package/local-cli/generator-web/index.js <==
'use strict';

var path = require('path');
var easyfile = require('easyfile');
var fs = require('fs');
module.exports = function(rootDir) {
  var src = path.join(__dirname, '/templates/');
  var dest = path.join(rootDir, 'web/');
  easyfile.copy(src, dest, {
    force: true,
    backup: true,
  });
  /**
   * 拷贝 react-dom.development.js 至 node_modules/react-dom/cjs/react-dom.development.js
   */
  easyfile.copy(rootDir +'/node_modules/@areslabs/jdreact-core-scripts/patch/react-dom/cjs/react-dom.development.js',
    rootDir +'/node_modules/react-dom/cjs/react-dom.development.js', {
     force: true,
     backup: false,
  });
  /**
   * 拷贝 version 文件至 web 目录下，并修改 moduleName
   */
  let fileName = process.cwd().split('-').pop()+'.version';
  let moduleName = process.cwd().split('-').pop();
  if(!easyfile.isFile(fileName)){
    var allfiles = fs.readdirSync(process.cwd()+'/jsbundles/');
    allfiles.forEach(function(item, index){
      if(path.extname(item) == '.version'){
        fileName = item;
        moduleName = path.basename(item,".version");
      }
    })
  }
  let sourceFile = path.join(process.cwd()+'/jsbundles/', fileName);
  let destFile = path.join(rootDir, 'web/version.json' );
  easyfile.copy(sourceFile, destFile, {
    force: true,
    backup: true,
  });

  /**
   * 修改moduleName
   */
  fs.readFile(destFile,'utf8',function (err, data) {
    if(err) console.log(err);
    var version = JSON.parse(data);
    version.moduleName = moduleName;
    var t = JSON.stringify(version);
    fs.writeFileSync(destFile,t);
  });

}
